@@ -615,6 +615,18 @@ class SurveyDynamic extends LSActiveRecord
         }
     }
 
+    /**
+     * @return string
+     */
+    public function getEmailForGrid()
+    {
+        // decrypt token information ( if needed )
+        $tokens = $this->tokens;
+        if (is_object($tokens)) {
+            return $tokens->email;
+        }
+    }
+
     /**
      * @return string
      */
